import { CustomParameterDecorator } from "./CustomParameterDecorator";
import { BaseDriver } from "./driver/BaseDriver";
import { MetadataArgsStorage } from "./metadata-builder/MetadataArgsStorage";
import { RoutingControllersOptions } from "./RoutingControllersOptions";
export * from "./container";
export * from "./decorator/Authorized";
export * from "./decorator/Body";
export * from "./decorator/BodyParam";
export * from "./decorator/ContentType";
export * from "./decorator/Controller";
export * from "./decorator/CookieParam";
export * from "./decorator/CookieParams";
export * from "./decorator/Ctx";
export * from "./decorator/CurrentUser";
export * from "./decorator/Delete";
export * from "./decorator/Get";
export * from "./decorator/Head";
export * from "./decorator/Header";
export * from "./decorator/HeaderParam";
export * from "./decorator/HeaderParams";
export * from "./decorator/HttpCode";
export * from "./decorator/Interceptor";
export * from "./decorator/JsonController";
export * from "./decorator/Location";
export * from "./decorator/Method";
export * from "./decorator/Middleware";
export * from "./decorator/OnNull";
export * from "./decorator/OnUndefined";
export * from "./decorator/Param";
export * from "./decorator/Params";
export * from "./decorator/Patch";
export * from "./decorator/Post";
export * from "./decorator/Put";
export * from "./decorator/QueryParam";
export * from "./decorator/QueryParams";
export * from "./decorator/Redirect";
export * from "./decorator/Render";
export * from "./decorator/Req";
export * from "./decorator/Res";
export * from "./decorator/ResponseClassTransformOptions";
export * from "./decorator/Session";
export * from "./decorator/State";
export * from "./decorator/UploadedFile";
export * from "./decorator/UploadedFiles";
export * from "./decorator/UseAfter";
export * from "./decorator/UseBefore";
export * from "./decorator/UseInterceptor";
export * from "./decorator-options/BodyOptions";
export * from "./decorator-options/ParamOptions";
export * from "./decorator-options/UploadOptions";
export * from "./http-error/HttpError";
export * from "./http-error/InternalServerError";
export * from "./http-error/BadRequestError";
export * from "./http-error/ForbiddenError";
export * from "./http-error/NotAcceptableError";
export * from "./http-error/MethodNotAllowedError";
export * from "./http-error/NotFoundError";
export * from "./http-error/UnauthorizedError";
export * from "./driver/express/ExpressMiddlewareInterface";
export * from "./driver/express/ExpressErrorMiddlewareInterface";
export * from "./driver/koa/KoaMiddlewareInterface";
export * from "./metadata-builder/MetadataArgsStorage";
export * from "./metadata/ActionMetadata";
export * from "./metadata/ControllerMetadata";
export * from "./metadata/InterceptorMetadata";
export * from "./metadata/MiddlewareMetadata";
export * from "./metadata/ParamMetadata";
export * from "./metadata/ResponseHandleMetadata";
export * from "./metadata/UseMetadata";
export * from "./RoutingControllersOptions";
export * from "./CustomParameterDecorator";
export * from "./RoleChecker";
export * from "./Action";
export * from "./InterceptorInterface";
export * from "./driver/BaseDriver";
export * from "./driver/express/ExpressDriver";
export * from "./driver/koa/KoaDriver";
/**
 * Gets metadata args storage.
 * Metadata args storage follows the best practices and stores metadata in a global variable.
 */
export declare function getMetadataArgsStorage(): MetadataArgsStorage;
/**
 * Registers all loaded actions in your express application.
 */
export declare function useExpressServer<T>(expressApp: T, options?: RoutingControllersOptions): T;
/**
 * Registers all loaded actions in your express application.
 */
export declare function createExpressServer(options?: RoutingControllersOptions): any;
/**
 * Registers all loaded actions in your koa application.
 */
export declare function useKoaServer<T>(koaApp: T, options?: RoutingControllersOptions): T;
/**
 * Registers all loaded actions in your koa application.
 */
export declare function createKoaServer(options?: RoutingControllersOptions): any;
/**
 * Registers all loaded actions in your application using selected driver.
 */
export declare function createServer<T extends BaseDriver>(driver: T, options?: RoutingControllersOptions): any;
/**
 * Registers all loaded actions in your express application.
 */
export declare function createExecutor<T extends BaseDriver>(driver: T, options?: RoutingControllersOptions): void;
/**
 * Registers custom parameter decorator used in the controller actions.
 */
export declare function createParamDecorator(options: CustomParameterDecorator): (object: Object, method: string, index: number) => void;
